Class: HelpScout::Folder

Inherits:
Object
  • Object
show all
Defined in:
lib/helpscout/models.rb

Overview

Folder http://developer.helpscout.net/objects/folder/

Name Type Example Notes id Int 1234 Unique identifier name String My Tickets Folder name type String mytickets The type this folder represents. userId Int 4532 If the folder type is TYPE_MY_TICKETS, userId represents the Help Scout user to which this folder belongs. Otherwise userId is 0. totalCount Int 2 Total number of conversations in this folder activeCount Int 1 Total number of conversations in this folder that are in an active state (vs pending). modifiedAt DateTime 2012-07-24T20:18:33Z UTC time when this folder was modified.

Possible values for type include:

  • TYPE_UNASSIGNED
  • TYPE_MY_TICKETS
  • TYPE_DRAFTS
  • TYPE_ASSIGNED
  • TYPE_CLOSED
  • TYPE_SPAM

Constant Summary collapse

TYPE_UNASSIGNED =
"open"
TYPE_MY_TICKETS =
"mytickets"
TYPE_DRAFTS =
"drafts"
TYPE_ASSIGNED =
"assigned"
TYPE_CLOSED =
"closed"
TYPE_SPAM =
"spam"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(object) ⇒ Folder

Creates a new Folder object from a Hash of attributes



897
898
899
900
901
902
903
904
905
906
# File 'lib/helpscout/models.rb', line 897

def initialize(object)
  @modifiedAt = DateTime.iso8601(object["modifiedAt"]) if object["modifiedAt"]

  @id = object["id"]
  @name = object["name"]
  @type = object["type"]
  @userId = object["userId"]
  @totalCount = object["totalCount"]
  @activeCount = object["activeCount"]
end

Instance Attribute Details

#activeCountObject (readonly)

Returns the value of attribute activeCount.



887
888
889
# File 'lib/helpscout/models.rb', line 887

def activeCount
  @activeCount
end

#idObject (readonly)

Returns the value of attribute id.



887
888
889
# File 'lib/helpscout/models.rb', line 887

def id
  @id
end

#modifiedAtObject (readonly)

Returns the value of attribute modifiedAt.



887
888
889
# File 'lib/helpscout/models.rb', line 887

def modifiedAt
  @modifiedAt
end

#nameObject (readonly)

Returns the value of attribute name.



887
888
889
# File 'lib/helpscout/models.rb', line 887

def name
  @name
end

#totalCountObject (readonly)

Returns the value of attribute totalCount.



887
888
889
# File 'lib/helpscout/models.rb', line 887

def totalCount
  @totalCount
end

#typeObject (readonly)

Returns the value of attribute type.



887
888
889
# File 'lib/helpscout/models.rb', line 887

def type
  @type
end

#userIdObject (readonly)

Returns the value of attribute userId.



887
888
889
# File 'lib/helpscout/models.rb', line 887

def userId
  @userId
end