Class: HelpScout::Source

Inherits:
Object
  • Object
show all
Defined in:
lib/helpscout/models.rb

Overview

Source http://developer.helpscout.net/objects/source/

Name Type Example Notes type String email The method from which this conversation (or thread) was created. via String customer

Possible values for type include:

  • TYPE_EMAIL
  • TYPE_WEB
  • TYPE_NOTIFICATION
  • TYPE_FWD

Possible values for via include:

  • VIA_USER
  • VIA_CUSTOMER

Constant Summary collapse

TYPE_EMAIL =
"email"
TYPE_WEB =
"web"
TYPE_NOTIFICATION =
"notification"
TYPE_FWD =
"emailfwd"
VIA_USER =
"user"
VIA_CUSTOMER =
"customer"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(object) ⇒ Source

Creates a new Source object from a Hash of attributes



850
851
852
853
# File 'lib/helpscout/models.rb', line 850

def initialize(object)
  @type = object["type"]
  @via = object["via"]
end

Instance Attribute Details

#typeObject (readonly)

Returns the value of attribute type.



839
840
841
# File 'lib/helpscout/models.rb', line 839

def type
  @type
end

#viaObject (readonly)

Returns the value of attribute via.



839
840
841
# File 'lib/helpscout/models.rb', line 839

def via
  @via
end